@@ -46,6 +46,7 @@ xsltNewDocument(xsltTransformContextPtr ctxt, xmlDocPtr doc) {
 
     cur = (xsltDocumentPtr) xmlMalloc(sizeof(xsltDocument));
     if (cur == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, (xmlNodePtr) doc);
         xsltGenericError(xsltGenericErrorContext,
 		"xsltNewDocument : malloc failed\n");
 	return(NULL);
@@ -73,6 +74,7 @@ xsltNewStyleDocument(xsltStylesheetPtr style, xmlDocPtr doc) {
 
     cur = (xsltDocumentPtr) xmlMalloc(sizeof(xsltDocument));
     if (cur == NULL) {
+	xsltPrintErrorContext(NULL, style, (xmlNodePtr) doc);
         xsltGenericError(xsltGenericErrorContext,
 		"xsltNewStyleDocument : malloc failed\n");
 	return(NULL);
@@ -165,6 +167,7 @@ xsltLoadDocument(xsltTransformContextPtr ctxt, const xmlChar *URI) {
 #ifdef LIBXML_XINCLUDE_ENABLED
 	xmlXIncludeProcess(doc);
 #else
+	xsltPrintErrorContext(ctxt, NULL, NULL);
         xsltGenericError(xsltGenericErrorContext,
 	    "xsltLoadDocument(%s) : XInclude processing not compiled in\n",
 	                 URI);
@@ -235,6 +238,8 @@ xsltFindDocument (xsltTransformContextPtr ctxt, xmlDocPtr doc) {
 	    return(ret);
 	ret = ret->next;
     }
+    if (doc==ctxt->style->doc)
+	return ctxt->style;
     return(NULL);
 }
 
