@@ -52,6 +52,7 @@ xsltNewStackElem(void) {
 
     cur = (xsltStackElemPtr) xmlMalloc(sizeof(xsltStackElem));
     if (cur == NULL) {
+	xsltPrintErrorContext(NULL, NULL, NULL);
         xsltGenericError(xsltGenericErrorContext,
 		"xsltNewStackElem : malloc failed\n");
 	return(NULL);
@@ -80,8 +81,9 @@ xsltCopyStackElem(xsltStackElemPtr elem) {
 
     cur = (xsltStackElemPtr) xmlMalloc(sizeof(xsltStackElem));
     if (cur == NULL) {
+	xsltPrintErrorContext(NULL, NULL, NULL);
         xsltGenericError(xsltGenericErrorContext,
-		"xsltNewStackElem : malloc failed\n");
+		"xsltCopyStackElem : malloc failed\n");
 	return(NULL);
     }
     cur->name = xmlStrdup(elem->name);
@@ -230,17 +232,17 @@ xsltStackLookup(xsltTransformContextPtr ctxt, const xmlChar *name,
     int i;
     xsltStackElemPtr cur;
 
-    if ((ctxt == NULL) || (name == NULL))
+    if ((ctxt == NULL) || (name == NULL) || (ctxt->varsNr == 0))
 	return(NULL);
 
     /*
      * Do the lookup from the top of the stack, but
      * don't use params being computed in a call-param
      */
-    i = ctxt->varsNr - 1;
+    ;
 
-    for (;i >= 0;i--) {
-	cur = ctxt->varsTab[i];
+    for (i = ctxt->varsNr; i > ctxt->varsBase; i--) {
+	cur = ctxt->varsTab[i-1];
 	while (cur != NULL) {
 	    if (xmlStrEqual(cur->name, name)) {
 		if (nameURI == NULL) {
@@ -271,6 +273,7 @@ xsltStackLookup(xsltTransformContextPtr ctxt, const xmlChar *name,
  * xsltEvalVariable:
  * @ctxt:  the XSLT transformation context
  * @elem:  the variable or parameter.
+ * @precomp: pointer to precompiled data
  *
  * Evaluate a variable value.
  *
@@ -281,7 +284,8 @@ xsltEvalVariable(xsltTransformContextPtr ctxt, xsltStackElemPtr elem,
 	         xsltStylePreCompPtr precomp) {
     xmlXPathObjectPtr result = NULL;
     int oldProximityPosition, oldContextSize;
-    xmlNodePtr oldInst;
+    xmlNodePtr oldInst, oldNode;
+    xsltDocumentPtr oldDoc;
     int oldNsNr;
     xmlNsPtr *oldNamespaces;
 
@@ -305,6 +309,8 @@ xsltEvalVariable(xsltTransformContextPtr ctxt, xsltStackElemPtr elem,
 	oldProximityPosition = ctxt->xpathCtxt->proximityPosition;
 	oldContextSize = ctxt->xpathCtxt->contextSize;
 	ctxt->xpathCtxt->node = (xmlNodePtr) ctxt->node;
+	oldDoc = ctxt->document;
+	oldNode = ctxt->node;
 	oldInst = ctxt->inst;
 	oldNsNr = ctxt->xpathCtxt->nsNr;
 	oldNamespaces = ctxt->xpathCtxt->namespaces;
@@ -323,9 +329,12 @@ xsltEvalVariable(xsltTransformContextPtr ctxt, xsltStackElemPtr elem,
 	ctxt->xpathCtxt->nsNr = oldNsNr;
 	ctxt->xpathCtxt->namespaces = oldNamespaces;
 	ctxt->inst = oldInst;
+	ctxt->node = oldNode;
+	ctxt->document = oldDoc;
 	if ((precomp == NULL) || (precomp->comp == NULL))
 	    xmlXPathFreeCompExpr(comp);
 	if (result == NULL) {
+	    xsltPrintErrorContext(ctxt, NULL, precomp->inst);
 	    xsltGenericError(xsltGenericErrorContext,
 		"Evaluating variable %s failed\n", elem->name);
 #ifdef WITH_XSLT_DEBUG_VARIABLE
@@ -346,7 +355,7 @@ xsltEvalVariable(xsltTransformContextPtr ctxt, xsltStackElemPtr elem,
 	     * This is a result tree fragment.
 	     */
 	    xmlNodePtr container;
-	    xmlNodePtr oldInsert, oldNode;
+	    xmlNodePtr oldInsert;
 
 	    container = xmlNewDocNode(ctxt->output, NULL,
 		                      (const xmlChar *) "fake", NULL);
@@ -354,11 +363,9 @@ xsltEvalVariable(xsltTransformContextPtr ctxt, xsltStackElemPtr elem,
 		return(NULL);
 
 	    oldInsert = ctxt->insert;
-	    oldNode = ctxt->node;
 	    ctxt->insert = container;
-	    xsltApplyOneTemplate(ctxt, ctxt->node, elem->tree, 0);
+	    xsltApplyOneTemplate(ctxt, ctxt->node, elem->tree, NULL, NULL);
 	    ctxt->insert = oldInsert;
-	    ctxt->node = oldNode;
 
 	    result = xmlXPathNewValueTree(container);
 	    if (result == NULL) {
@@ -379,8 +386,8 @@ xsltEvalVariable(xsltTransformContextPtr ctxt, xsltStackElemPtr elem,
 
 /**
  * xsltEvalGlobalVariable:
- * @ctxt:  the XSLT transformation context
  * @elem:  the variable or parameter.
+ * @ctxt:  the XSLT transformation context
  *
  * Evaluate a global variable value.
  *
@@ -441,6 +448,7 @@ xsltEvalGlobalVariable(xsltStackElemPtr elem, xsltTransformContextPtr ctxt) {
 	if ((precomp == NULL) || (precomp->comp == NULL))
 	    xmlXPathFreeCompExpr(comp);
 	if (result == NULL) {
+	    xsltPrintErrorContext(ctxt, NULL, precomp->inst);
 	    xsltGenericError(xsltGenericErrorContext,
 		"Evaluating global variable %s failed\n", elem->name);
 #ifdef WITH_XSLT_DEBUG_VARIABLE
@@ -461,7 +469,7 @@ xsltEvalGlobalVariable(xsltStackElemPtr elem, xsltTransformContextPtr ctxt) {
 	     * This is a result tree fragment.
 	     */
 	    xmlNodePtr container;
-	    xmlNodePtr oldInsert, oldNode;
+	    xmlNodePtr oldInsert;
 
 	    container = xmlNewDocNode(ctxt->output, NULL,
 		                      (const xmlChar *) "fake", NULL);
@@ -469,11 +477,9 @@ xsltEvalGlobalVariable(xsltStackElemPtr elem, xsltTransformContextPtr ctxt) {
 		return(NULL);
 
 	    oldInsert = ctxt->insert;
-	    oldNode = ctxt->node;
 	    ctxt->insert = container;
-	    xsltApplyOneTemplate(ctxt, ctxt->node, elem->tree, 0);
+	    xsltApplyOneTemplate(ctxt, ctxt->node, elem->tree, NULL, NULL);
 	    ctxt->insert = oldInsert;
-	    ctxt->node = oldNode;
 
 	    result = xmlXPathNewValueTree(container);
 	    if (result == NULL) {
@@ -553,6 +559,7 @@ xsltEvalGlobalVariables(xsltTransformContextPtr ctxt) {
 				 elem->name, elem->nameURI, def);
 	    } else if ((elem->comp != NULL) &&
 		       (elem->comp->type == XSLT_FUNC_VARIABLE)) {
+		xsltPrintErrorContext(ctxt, style, elem->comp->inst);
 		xsltGenericError(xsltGenericErrorContext,
 		    "Global variable %s already defined\n", elem->name);
 	    }
@@ -642,7 +649,7 @@ xsltRegisterGlobalVariable(xsltStylesheetPtr style, const xmlChar *name,
  * @ctxt:  the XSLT transformation context
  * @params:  a NULL terminated arry of parameters names/values tuples
  *
- * Evaluate the global variables of a stylesheet. This need to be
+ * Evaluate the global variables of a stylesheet. This needs to be
  * done on parsed stylesheets before starting to apply transformations
  *
  * Returns 0 in case of success, -1 in case of error
@@ -690,6 +697,7 @@ xsltEvalUserParams(xsltTransformContextPtr ctxt, const char **params) {
 		ns = xmlSearchNs(style->doc, xmlDocGetRootElement(style->doc),
 			         prefix);
 		if (ns == NULL) {
+		    xsltPrintErrorContext(ctxt, style, NULL);
 		    xsltGenericError(xsltGenericErrorContext,
 		    "user param : no namespace bound to prefix %s\n", prefix);
 		    href = NULL;
@@ -732,6 +740,7 @@ xsltEvalUserParams(xsltTransformContextPtr ctxt, const char **params) {
 	    xmlXPathFreeCompExpr(comp);
 	}
 	if (result == NULL) {
+	    xsltPrintErrorContext(ctxt, style, NULL);
 	    xsltGenericError(xsltGenericErrorContext,
 		"Evaluating user parameter %s failed\n", name);
 	} else {
@@ -768,6 +777,7 @@ xsltEvalUserParams(xsltTransformContextPtr ctxt, const char **params) {
 			     ncname, href, elem);
 	    if (res != 0) {
 		xsltFreeStackElem(elem);
+		xsltPrintErrorContext(ctxt, style, NULL);
 		xsltGenericError(xsltGenericErrorContext,
 		    "Global parameter %s already defined\n", ncname);
 	    }
@@ -825,9 +835,7 @@ xsltBuildVariable(xsltTransformContextPtr ctxt, xsltStylePreCompPtr comp,
 /**
  * xsltRegisterVariable:
  * @ctxt:  the XSLT transformation context
- * @name:  the variable name
- * @ns_uri:  the variable namespace URI
- * @select:  the expression which need to be evaluated to generate a value
+ * @comp:  pointer to precompiled data
  * @tree:  the tree if select is NULL
  * @param:  this is a parameter actually
  *
@@ -842,13 +850,14 @@ xsltRegisterVariable(xsltTransformContextPtr ctxt, xsltStylePreCompPtr comp,
 
     if (xsltCheckStackElem(ctxt, comp->name, comp->ns) != 0) {
 	if (!param) {
+	    xsltPrintErrorContext(ctxt, NULL, comp->inst);
 	    xsltGenericError(xsltGenericErrorContext,
 	    "xsl:variable : redefining %s\n", comp->name);
 	}
 #ifdef WITH_XSLT_DEBUG_VARIABLE
 	else
 	    xsltGenericDebug(xsltGenericDebugContext,
-		     "param %s defined by caller", comp->name);
+		     "param %s defined by caller\n", comp->name);
 #endif
 	return(0);
     }
@@ -956,12 +965,14 @@ xsltParseStylesheetCallerParam(xsltTransformContextPtr ctxt, xmlNodePtr cur) {
 	return(NULL);
     comp = (xsltStylePreCompPtr) cur->_private;
     if (comp == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, cur);
 	xsltGenericError(xsltGenericErrorContext,
 	    "xsl:param : compilation error\n");
 	return(NULL);
     }
 
     if (comp->name == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, cur);
 	xsltGenericError(xsltGenericErrorContext,
 	    "xsl:param : missing name attribute\n");
 	return(NULL);
@@ -1006,12 +1017,14 @@ xsltParseGlobalVariable(xsltStylesheetPtr style, xmlNodePtr cur) {
     xsltStylePreCompute(style, cur);
     comp = (xsltStylePreCompPtr) cur->_private;
     if (comp == NULL) {
+	xsltPrintErrorContext(NULL, style, cur);
 	xsltGenericError(xsltGenericErrorContext,
-	     "xsl:variable : compilation had failed\n");
+	     "xsl:variable : compilation failed\n");
 	return;
     }
 
     if (comp->name == NULL) {
+	xsltPrintErrorContext(NULL, style, cur);
 	xsltGenericError(xsltGenericErrorContext,
 	    "xsl:variable : missing name attribute\n");
 	return;
@@ -1045,12 +1058,14 @@ xsltParseGlobalParam(xsltStylesheetPtr style, xmlNodePtr cur) {
     xsltStylePreCompute(style, cur);
     comp = (xsltStylePreCompPtr) cur->_private;
     if (comp == NULL) {
+	xsltPrintErrorContext(NULL, style, cur);
 	xsltGenericError(xsltGenericErrorContext,
-	     "xsl:param : compilation had failed\n");
+	     "xsl:param : compilation failed\n");
 	return;
     }
 
     if (comp->name == NULL) {
+	xsltPrintErrorContext(NULL, style, cur);
 	xsltGenericError(xsltGenericErrorContext,
 	    "xsl:param : missing name attribute\n");
 	return;
@@ -1083,12 +1098,14 @@ xsltParseStylesheetVariable(xsltTransformContextPtr ctxt, xmlNodePtr cur) {
 
     comp = (xsltStylePreCompPtr) cur->_private;
     if (comp == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, cur);
 	xsltGenericError(xsltGenericErrorContext,
-	     "xsl:variable : compilation had failed\n");
+	     "xsl:variable : compilation failed\n");
 	return;
     }
 
     if (comp->name == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, cur);
 	xsltGenericError(xsltGenericErrorContext,
 	    "xsl:variable : missing name attribute\n");
 	return;
@@ -1120,12 +1137,14 @@ xsltParseStylesheetParam(xsltTransformContextPtr ctxt, xmlNodePtr cur) {
 
     comp = (xsltStylePreCompPtr) cur->_private;
     if (comp == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, cur);
 	xsltGenericError(xsltGenericErrorContext,
-	     "xsl:param : compilation had failed\n");
+	     "xsl:param : compilation failed\n");
 	return;
     }
 
     if (comp->name == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, cur);
 	xsltGenericError(xsltGenericErrorContext,
 	    "xsl:param : missing name attribute\n");
 	return;
@@ -1179,6 +1198,7 @@ xsltXPathVariableLookup(void *ctxt, const xmlChar *name,
     context = (xsltTransformContextPtr) ctxt;
     ret = xsltVariableLookup(context, name, ns_uri);
     if (ret == NULL) {
+	xsltPrintErrorContext(ctxt, NULL, NULL);
 	xsltGenericError(xsltGenericErrorContext,
 	    "unregistered variable %s\n", name);
     }
