@@ -272,6 +272,73 @@ xsltSetGenericDebugFunc(void *ctx, xmlGenericErrorFunc handler) {
 	xsltGenericDebug = xsltGenericDebugDefaultFunc;
 }
 
+/**
+ * xsltPrintErrorContext:
+ * @ctxt:  the transformation context
+ * @style:  the stylesheet
+ * @node:  the current node being processed
+ *
+ * Display the context of an error.
+ */
+void
+xsltPrintErrorContext(xsltTransformContextPtr ctxt,
+	              xsltStylesheetPtr style, xmlNodePtr node) {
+    int line = 0;
+    const xmlChar *file = NULL;
+    const xmlChar *name = NULL;
+    const char *type = "error";
+
+    if ((node != NULL) && (ctxt != NULL))
+	node = ctxt->inst;
+
+    if (node != NULL)  {
+	if ((node->type == XML_DOCUMENT_NODE) ||
+	    (node->type == XML_HTML_DOCUMENT_NODE)) {
+	    xmlDocPtr doc = (xmlDocPtr) node;
+
+	    file = doc->URL;
+	} else {
+	    if (node->type == XML_ELEMENT_NODE) {
+		line = (int) node->content;
+	    }
+	    if ((node->doc != NULL) && (node->doc->URL != NULL))
+		file = node->doc->URL;
+	    if (node->name != NULL)
+		name = node->name;
+	}
+    } 
+    
+    if (ctxt != NULL)
+	type = "runtime error";
+    else if (style != NULL)
+	type = "compilation error";
+
+    if ((file != NULL) && (line != 0) && (name != NULL))
+	xsltGenericError(xsltGenericErrorContext,
+		"%s: file %s line %d element %s\n",
+		type, file, line, name);
+    else if ((file != NULL) && (name != NULL))
+	xsltGenericError(xsltGenericErrorContext,
+		"%s: file %s element %s\n",
+		type, file, name);
+    else if ((file != NULL) && (line != 0))
+	xsltGenericError(xsltGenericErrorContext,
+		"%s: file %s line %d\n",
+		type, file, line);
+    else if (file != NULL)
+	xsltGenericError(xsltGenericErrorContext,
+		"%s: file %s\n",
+		type, file);
+    else if (name != NULL)
+	xsltGenericError(xsltGenericErrorContext,
+		"%s: element %s\n",
+		type, name);
+    else
+	xsltGenericError(xsltGenericErrorContext,
+		"%s\n",
+		type);
+}
+
 /************************************************************************
  * 									*
  * 				QNames					*
@@ -964,6 +1031,8 @@ xsltSaveResultToFd(int fd, xmlDocPtr result, xsltStylesheetPtr style) {
  * 									*
  ************************************************************************/
 
+static long calibration = -1;
+
 /**
  * xsltCalibrateTimestamps:
  *
@@ -981,39 +1050,84 @@ xsltCalibrateTimestamps(void) {
     return(xsltTimestamp() / 1000);
 }
 
+/**
+ * xsltCalibrateAdjust:
+ * @delta:  a negative dealy value found
+ *
+ * Used for to correct the calibration for xsltTimestamp()
+ */
+void
+xsltCalibrateAdjust(long delta) {
+    calibration += delta;
+}
+
 /**
  * xsltTimestamp:
  *
  * Used for gathering profiling data
  *
- * Returns the number of milliseconds since the beginning of the
+ * Returns the number of tenth of milliseconds since the beginning of the
  * profiling
  */
 long
-xsltTimestamp(void) {
+xsltTimestamp(void)
+{
 #ifdef HAVE_GETTIMEOFDAY
-    static long calibration = -1;
     static struct timeval startup;
     struct timeval cur;
-    long msec;
+    long tics;
 
-    if (calibration == -1) {
-	gettimeofday(&startup, NULL);
-	calibration = 0;
-	calibration = xsltCalibrateTimestamps();
-	gettimeofday(&startup, NULL);
-	return(0);
+    if (calibration < 0) {
+        gettimeofday(&startup, NULL);
+        calibration = 0;
+        calibration = xsltCalibrateTimestamps();
+        gettimeofday(&startup, NULL);
+        return (0);
     }
 
     gettimeofday(&cur, NULL);
-    msec = cur.tv_sec - startup.tv_sec;
-    msec *= 10000;
-    msec += (cur.tv_usec - startup.tv_usec) / 100;
+    tics = (cur.tv_sec - startup.tv_sec) * XSLT_TIMESTAMP_TICS_PER_SEC;
+    tics += (cur.tv_usec - startup.tv_usec) /
+                          (1000000l / XSLT_TIMESTAMP_TICS_PER_SEC);
     
-    msec -= calibration;
-    return((unsigned long) msec);
+    tics -= calibration;
+    return(tics);
 #else
-    return(0);
+#ifdef XSLT_WIN32_PERFORMANCE_COUNTER
+
+    BOOL ok;
+    LARGE_INTEGER performanceCount;
+    LARGE_INTEGER performanceFrequency;
+    LONGLONG quadCount;
+    double seconds;
+    static LONGLONG startupQuadCount = 0;
+    static LONGLONG startupQuadFreq = 0;
+
+    ok = QueryPerformanceCounter(&performanceCount);
+    if (!ok)
+        return 0;
+    quadCount = performanceCount.QuadPart;
+    if (calibration < 0) {
+        calibration = 0;
+        ok = QueryPerformanceFrequency(&performanceFrequency);
+        if (!ok)
+            return 0;
+        startupQuadFreq = performanceFrequency.QuadPart;
+        startupQuadCount = quadCount;
+        return (0);
+    }
+    if (startupQuadFreq == 0)
+        return 0;
+    seconds = (quadCount - startupQuadCount) / (double) startupQuadFreq;
+    return (long) (seconds * XSLT_TIMESTAMP_TICS_PER_SEC);
+
+#else /* XSLT_WIN32_PERFORMANCE_COUNTER */
+
+    /* Neither gettimeofday() nor Win32 performance counter available */
+
+    return (0);
+
+#endif /* XSLT_WIN32_PERFORMANCE_COUNTER */
 #endif
 }
 
